/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: Finder.java,v 584a8002bbf7 2010/07/17 13:10:42 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.taxonomy;

import javax.annotation.Nonnull;

/***********************************************************************************************************************
 *
 * A facility for performing queries on an {@link ObservationSet}. This class implements the
 * <a href="http://en.wikipedia.org/wiki/Fluent_interface">Fluent Interface</a> pattern. A typical usage is:
 *
 * <pre>
 * ObservationSet observationSet = ...;
 * List&lt;Observable&gt; results = observationSet.find(Observable.class).
 *                                           from(10).
 *                                           max(20).
 *                                           sort(SortCriterion.DISPLAY_NAME, SortDirection.ASCENDING).
 *                                           results();
 * </pre>
 *
 * @author  Fabrizio Giudici
 * @version $Id: Finder.java,v 584a8002bbf7 2010/07/17 13:10:42 fabrizio $
 *
 **********************************************************************************************************************/
public interface Finder<T> extends it.tidalwave.util.Finder<T>
  {
    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public static enum SortCriterion implements it.tidalwave.util.Finder.SortCriterion
      {
        DISPLAY_NAME
      }

    /*******************************************************************************************************************
     *
     * Sets the name for the query. Only entities with the given name will be returned.
     *
     * @param  name  the name
     * @return       the finder itself
     *
     ******************************************************************************************************************/
    @Nonnull
    public Finder<T> name (@Nonnull final String name);
  }
