/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: TaxonomyManager.java,v 881d7c7444c2 2010/07/17 14:35:37 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.taxonomy;

import it.tidalwave.util.NotFoundException;
import javax.annotation.Nonnull;
import org.openide.util.Lookup;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: TaxonomyManager.java,v 881d7c7444c2 2010/07/17 14:35:37 fabrizio $
 *
 **********************************************************************************************************************/
public interface TaxonomyManager extends Lookup.Provider
  {
    /*******************************************************************************************************************
     *
     * The Service Locator for {@link TaxonomyManager}.
     *
     ******************************************************************************************************************/
    public final class Locator
      {
        private Locator()
          {
          }

        /***************************************************************************************************************
         *
         * Gets a reference to the {@link TaxonomyManager}.
         *
         **************************************************************************************************************/
        @Nonnull
        public static final TaxonomyManager findTaxonomyManager()
          {
            final Lookup lookup = Lookup.getDefault();
            final TaxonomyManager taxonomyManager = lookup.lookup(TaxonomyManager.class);

            if (taxonomyManager == null)
              {
                throw new RuntimeException("Cannot lookup TaxonomyManager");
              }

            return taxonomyManager;
          }
      }

    /*******************************************************************************************************************
     *
     * Creates a {@link Taxonomy}.
     *
     * @param  displayName  the name of the {@code Taxonomy} to retrieve
     * @param  id           the id of the {@code Taxonomy}
     * @param  repository   the repository for persistence
     * @return              the {@code Taxonomy}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Taxonomy createTaxonomy (@Nonnull final String displayName,
                                    @Nonnull final String id,
                                    @Nonnull final Object repository);

    /*******************************************************************************************************************
     *
     * Finds a {@link Taxonomy} in an existing repository.
     *
     * @param  displayName  the name of the {@code Taxonomy} to retrieve
     * @param  repository   the repository
     * @return              the {@code Taxonomy}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Taxonomy findTaxonomyByName (@Nonnull final String displayName,
                                        @Nonnull final Object repository)
      throws NotFoundException;
  }
